@@ -5,11 +5,11 @@
 
 # usage
 # cd libaunit-<version>/debian
-# sudo schroot ./test_installed.sh
+# soversion=*; aliversion=*; debversion=*; sudo schroot ./test_installed.sh
 
 # This re-installs the latest version.
-sudo dpkg --install ../../libaunit3_1.03-5_i386.deb
-sudo dpkg --install ../../libaunit1-dev_1.03-5_i386.deb
+sudo dpkg --install ../../libaunit${soversion}_1.03-${debversion}_i386.deb
+sudo dpkg --install ../../libaunit${aliversion}-dev_1.03-${debversion}_i386.deb
 
 # tmp is owned by root; we need write permission
 sudo chmod o+w tmp
